# Create some drawings for back-to-back drawing activities

# The size of the drawing area on screen will be what is used for the
# postscript output so make it larger if there is cropping


from turtle import *            # We'll be using turtle stuff

# Make a square of given size
def square(size):
    for i in range(4):
        forward(size)
        right(90)

# Make a 5-pointed star of given size
def star(size):
    points = 5
    for i in range(points):
        forward(size)
        right(2*360/points)

# Make first drawing: grid of squares and stars
def drawing1():
    speed(0)                    # Go fast

    clear()                     # Erase everything
    penup()                     # Don't draw
    goto(-350,300)              # while moving
    pendown()                   # No draw
    for i in range(4):          # Repeatedly
        square(20*(i+1))        # Draw squares
        penup()
        forward(200)
        pendown()

    penup()
    goto(300,100)
    pendown()
    for i in range(4):          # Repeatedly 
        star(20*(i+1))          # Draw stars
        penup()
        backward(200)
        pendown()

    penup()
    goto(-350,-100)
    pendown()
    for i in range(4):          # Repeatedly
        if(i % 2 == 0):         # i even: draw square
            square(100)
        else:                   # i odd: draw star
            star(100)
        penup()
        forward(200)
        pendown()
    hideturtle()                # Save to a file
    getcanvas().postscript(file="drawing1.ps")
    showturtle()

# Drawing 2: diagonal alternating star/circle    
def drawing2():
    speed(0)

    clear()
    penup()
    goto(-350,300)
    pendown()
    for i in range(5):          # Repeatedly
        if(i % 2 == 0):         # even: draw star
            star(20*(i+1))
        else:                   # odd: draw circle
            circle(50)
        penup()
        setheading(315)
        forward(200)
        pendown()
        setheading(0)
        
    penup()                     # Place a square in
    goto(-200,-200)             # in the lower left
    pendown()
    square(100)

    penup()                     # Place a turtle
    goto(+200,+200)             # in the upper right
    pendown()
    shape("turtle")
    shapesize(10,10,10)
    stamp()

    hideturtle()                # Save
    getcanvas().postscript(file="drawing2.ps")
    showturtle()

    
# Drawing 3: two offset grids of circles
def drawing3():
    speed(0)

    xorigin = -300
    yorigin = 100

    for k in range(2):
        xstart = xorigin
        ystart = yorigin

        for j in range(2):
    
            penup()
            goto(xstart,ystart)
            pendown()
            
            for i in range(7):
                circle(50)
                penup()
                forward(100)
                pendown()
    
            ystart -= 100

        
        xorigin -= 50
        yorigin -= 0

    xorigin = -300
    yorigin = -200

    for k in range(2):
        xstart = xorigin
        ystart = yorigin

        for j in range(2):
    
            penup()
            goto(xstart,ystart)
            pendown()
            
            for i in range(7):
                circle(50)
                penup()
                forward(100)
                pendown()
    
            ystart -= 100

        
        xorigin -= 0
        yorigin -= 50

    hideturtle()
#    getcanvas().postscript(file="drawing3.ps")
    showturtle()

# drawing1()
# drawing2()
# drawing3()

# Screen().mainloop()             # Wait for user to close window
